@@ -1,7 +1,7 @@
 ##' Get a survey, either from its Zenodo repository, a set of files, or a survey variable
 ##'
 ##' @description Downloads survey data, or extracts them from files, and returns a clean data set.
-##' @param survey a DOI (see \code{\link{list_surveys}}), or a numerical id (corresponding to the numbers returned in the \code{id} column returned by \code{\link{list_surveys}}), or a character vector of file names, or a \code{\link{survey}} object (in which case only cleaning is done).
+##' @param survey a DOI (see \code{\link{list_surveys}}), or a character vector of file names, or a \code{\link{survey}} object (in which case only cleaning is done).
 ##' @param quiet if TRUE, suppress messages
 ##' @param ... options for \code{\link{clean}}, which is called at the end of this
 ##' @importFrom httr GET add_headers content
@@ -32,14 +32,6 @@ get_survey <- function(survey, quiet=FALSE, ...)
         new_survey <- survey
     } else
     {
-        if (is.numeric(survey)) survey <- as.integer(survey)
-        if (is.integer(survey))
-        {
-            if (length(survey) > 1) stop("if 'survey' is a number, it must be of length 1")
-            ls <- list_surveys()
-            survey <- ls[id == survey]$url
-        }
-
         if (is.character(survey))
         {
             if (length(survey) > 1)
